@@ -1,6 +1,6 @@
 package Bundle::Business::Shipping;
 
-$VERSION = '1.09';
+$VERSION = '1.11';
 
 1;
 
@@ -18,8 +18,6 @@ See the INSTALL file in Business::Shipping for more information.
 
 =head1 CONTENTS
 
-Bundle::DBD::CSV
-
 Business::Shipping
 
 Business::Shipping::DataFiles
@@ -38,9 +36,7 @@ Log::Log4perl
 
 LWP::UserAgent
 
-Math::BaseCnv
-
-Scalar::Util        1.10
+Scalar::Util
 
 XML::DOM
 
